package saferepo.persistence;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.StandardCopyOption;

import saferepo.model.Document;
import saferepo.model.VersionedDocument;

public class MyRepoPersister extends AbstractRepoPersister {
	
	public MyRepoPersister(Path repoPath) throws SadPersisterException {
		super(repoPath);
	}
	
	
	@Override
	public void store(VersionedDocument vdoc) throws SadPersisterException {
		String targetName = vdoc.getPath().getFileName() + "_"+ vdoc.getVersion() + "_"+ vdoc.getTimeStamp().toString().replace(':', '_') ;
		try {
			Files.copy(vdoc.getPath(), this.repoPath.resolve(targetName), StandardCopyOption.REPLACE_EXISTING);
		} catch (IOException e) {
			throw new SadPersisterException("Errore nel salvataggio del documento nella cartella del persister");
		}
	}
	
	@Override
	public VersionedDocument retrieve(VersionedDocument vdoc, Path destDir) throws SadPersisterException {
		String targetName = vdoc.getPath().getFileName() + "_"+ vdoc.getVersion() + "_"+ vdoc.getTimeStamp().toString().replace(':', '_') ;
		try {
			Path copiedFile = Files.copy(this.repoPath.resolve(targetName), destDir.resolve(vdoc.getPath().getFileName()), StandardCopyOption.REPLACE_EXISTING);
			return new VersionedDocument(new Document(vdoc.getID(),copiedFile), vdoc.getTimeStamp(), vdoc.getVersion());
		} catch (IOException e) {
			throw new SadPersisterException("Errore nella copia del documento " + targetName + " in "+ destDir.toString() + ", directory di destinazione inesistente?" );
		}
	}
	
	/*
	public static void main(String[] args) throws InterruptedException, SadPersisterException, IOException {
		Document fakeDoc1 = new Document("doc1", Paths.get("C:/temp/doc1"));
		Document fakeDoc2 = new Document("doc2", Paths.get("C:/temp/doc2"));
		Document fakeDoc3 = new Document("doc3", Paths.get("C:/temp/doc3"));
		
		System.out.println("---fase 1---");
		
		VersionedDocument vdoc1_1 = new VersionedDocument(fakeDoc1, LocalDateTime.parse("2018-12-31T15:39:02.154254"), 1);
		VersionedDocument vdoc1_2 = new VersionedDocument(fakeDoc1, LocalDateTime.parse("2018-12-31T15:39:03.318918"), 2);
		VersionedDocument vdoc1_3 = new VersionedDocument(fakeDoc1, LocalDateTime.parse("2018-12-31T15:39:17.487524"), 3);
		
		VersionedDocument vdoc2_1 = new VersionedDocument(fakeDoc2, LocalDateTime.parse("2018-12-31T15:47:53.652415"), 1);
		VersionedDocument vdoc2_2 = new VersionedDocument(fakeDoc2, LocalDateTime.parse("2018-12-31T15:48:03.252415"), 2);
		
		VersionedDocument vdoc3_1 = new VersionedDocument(fakeDoc3, LocalDateTime.parse("2018-12-31T15:51:21.652415"), 1);
		VersionedDocument vdoc3_2 = new VersionedDocument(fakeDoc3, LocalDateTime.parse("2018-12-31T15:51:22.652415"), 2);
		VersionedDocument vdoc3_3 = new VersionedDocument(fakeDoc3, LocalDateTime.parse("2018-12-31T15:51:23.652415"), 3);
	
		System.out.println("---fase 2---");

		System.out.println(vdoc1_1);
		System.out.println(vdoc1_2);
		System.out.println(vdoc1_3);
		System.out.println(vdoc2_1);
		System.out.println(vdoc2_2);
		System.out.println(vdoc3_1);
		System.out.println(vdoc3_2);
		System.out.println(vdoc3_3);

		System.out.println("---fase 3---");

		RepoPersister persister = new MyRepoPersister(Paths.get("C:\\Temp\\repotmp"));
		
		System.out.println("---fase 4---");

		persister.store(vdoc1_2);
		persister.store(vdoc2_1);
		persister.store(vdoc3_3);
		
		System.out.println("---fase 5---");

		Files.list(Paths.get("C:\\Temp")).forEach(System.out::println);
	}
	*/

}
